@@ -318,7 +318,23 @@ def obj1018(xobj):
 
 
 def obj1019(xobj):
-    return {"opening": xobj[0]}
+    open = xobj[0]
+    if open == 0:
+        opening = 1
+        status = "opened"
+    elif open == 1:
+        opening = 0
+        status = "closed"
+    elif open == 2:
+        opening = 1
+        status = "closing timeout"
+    elif open == 3:
+        opening = 1
+        status = "device reset"
+    else:
+        opening = 0
+        status = None
+    return {"opening": opening, "status": status}
 
 
 def obj100a(xobj):
@@ -458,7 +474,7 @@ def parse_xiaomi(self, data, source_mac, rssi):
         sinfo += ', Standard certification'
 
     # check for MAC presence in sensor whitelist, if needed
-    if self.discovery is False and xiaomi_mac.lower() not in self.sensor_whitelist:
+    if self.discovery is False and xiaomi_mac not in self.sensor_whitelist:
         _LOGGER.debug("Discovery is disabled. MAC: %s is not whitelisted!", to_mac(xiaomi_mac))
         return None
 
